From 058a7659ba2590dbc067fe76bb6044e0d4f9b192 Mon Sep 17 00:00:00 2001
From: Aanand Prasad <aanand.prasad@gmail.com>
Date: Wed, 22 Jun 2016 14:53:45 -0700
Subject: [PATCH] Update bundle extension

It's now .dab, for Distributed Application Bundle

Signed-off-by: Aanand Prasad <aanand.prasad@gmail.com>
---
 compose/cli/main.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/compose/cli/main.py b/compose/cli/main.py
index 25ee90507..ae0175d5f 100644
--- a/compose/cli/main.py
+++ b/compose/cli/main.py
@@ -217,7 +217,7 @@ class TopLevelCommand(object):
 
     def bundle(self, config_options, options):
         """
         Generate a Docker bundle from the Compose file.
 
         Images must have digests stored, which requires interaction with a
         Docker registry. If digests aren't stored for all images, you can pass
@@ -231,14 +231,14 @@ class TopLevelCommand(object):
             --fetch-digests            Automatically fetch image digests if missing
 
             -o, --output PATH          Path to write the bundle file to.
-                                       Defaults to "<project name>.dsb".
+                                       Defaults to "<project name>.dab".
         """
         self.project = project_from_options('.', config_options)
         compose_config = get_config_from_options(self.project_dir, config_options)
 
         output = options["--output"]
         if not output:
-            output = "{}.dsb".format(self.project.name)
+            output = "{}.dab".format(self.project.name)
 
         with errors.handle_connection_errors(self.project.client):
             try:
@@ -217,7 +217,7 @@ class TopLevelCommand(object):
     def bundle(self, config_options, options):
         """
-        Generate a Docker bundle from the Compose file.
+        Generate a Distributed Application Bundle (DAB) from the Compose file.
 
         Images must have digests stored, which requires interaction with a